/*
 * @Company: hugeInfo
 * @Author: lwh
 * @Date: 2023-04-18 10:19:58
 * @LastEditTime: 2023-05-18 16:31:43
 * @LastEditors: lwh
 * @Version: 1.0.0
 * @Description: 走访列表 - 列表组件
 */
import React, { useEffect } from 'react';
import { useHistory } from 'react-router-dom';
import { Space } from 'dingtalk-design-mobile';
import MyList from '../MyList';
import { dateFormat, getUpdateStr, searchTitle } from '../../utils/utility';
import { visit_1 } from '../../assets/img';
import routerStatus from '../../status/router';

const VisitList = ({ search, data, hasMore, getScrollTopKey, scrollTop, searchValue, getTrailArriveData }) => {
  const history = useHistory();

  // 加载更多数据
  function handleLoadMore(callback) {
    getTrailArriveData({ ...search, page: search.page + 1 }, '', callback);
  }

  // 房间更新
  useEffect(() => {
    if (routerStatus.spinPage['visitList']) {
      getTrailArriveData({ ...search, page: 1, size: search.page * search.size }, 'spin');
      routerStatus.setPageScrollTopNow('visitList');
      routerStatus.clearSpinPage('visitList');
    }
  }, [routerStatus.spinPage['visitList']]);

  return (
    <MyList
      data={data}
      hasMore={hasMore}
      loadMore={handleLoadMore}
      getScrollTopKey={getScrollTopKey}
      scrollTop={scrollTop}
      itemDom={(item, index) => {
        return (
          <div
            className="building-card-bottom"
            style={index === 0 ? { marginTop: 0 } : null}
            onClick={() => history.push(`/hztGrid/visit?id=${item.houseId}`)}
          >
            <div className="building-card">
              <div className="building-title">
                <span>{searchValue ? searchTitle(item.houseaddress, searchValue) : item.houseaddress}</span>
              </div>
              <div className="building-subtitle">
                <div className="building-subtitle-text">{item.familyCount || 0}分户</div>
                <div className="public-split" />
                <div className="building-subtitle-text">{item.personCount || 0}人口</div>
              </div>
              <Space>
                {item.arriveQuarterOne ? <div className="public-tag2 public-tag2-blue">第一轮<img style={{ width: "12px", height: '12px', paddingLeft: '4px' }} src={visit_1} /></div> : <div className="public-tag2">第一轮</div>}
                {item.arriveQuarterTwo ? <div className="public-tag2 public-tag2-blue">第二轮<img style={{ width: "12px", height: '12px', paddingLeft: '4px' }} src={visit_1} /></div> : <div className="public-tag2">第二轮</div>}
                {item.arriveQuarterThree ? <div className="public-tag2 public-tag2-blue">第三轮<img style={{ width: "12px", height: '12px', paddingLeft: '4px' }} src={visit_1} /></div> : <div className="public-tag2">第三轮</div>}
                {item.arriveQuarterFour ? <div className="public-tag2 public-tag2-blue">第四轮<img style={{ width: "12px", height: '12px', paddingLeft: '4px' }} src={visit_1} /></div> : <div className="public-tag2">第四轮</div>}
              </Space>
            </div>
          </div>
        );
      }}
    />
  );
};

export default VisitList;